# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/asset/link/link.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/asset/link/link.proto',
  package='v3.asset.link',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x18v3/asset/link/link.proto\x12\rv3.asset.link\"%\n\x06Header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"%\n\x06\x43ookie\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"7\n\x0cLocalStorage\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\x0b\n\x03key\x18\x02 \x02(\t\x12\r\n\x05value\x18\x03 \x02(\t\"6\n\tFormInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\"A\n\x04\x46orm\x12(\n\x06inputs\x18\x01 \x03(\x0b\x32\x18.v3.asset.link.FormInput\x12\x0f\n\x07\x65nctype\x18\x02 \x02(\t\">\n\x0e\x46ormCredential\x12\r\n\x05login\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"\"\n\x10ScriptCredential\x12\x0e\n\x06script\x18\x01 \x01(\t\"\xac\x03\n\x07Message\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\x0e\n\x06method\x18\x02 \x02(\t\x12\x0e\n\x04\x62ody\x18\x03 \x01(\x0cH\x00\x12#\n\x04\x66orm\x18\x04 \x01(\x0b\x32\x13.v3.asset.link.FormH\x00\x12,\n\rextra_headers\x18\x05 \x03(\x0b\x32\x15.v3.asset.link.Header\x12&\n\x07\x63ookies\x18\x06 \x03(\x0b\x32\x15.v3.asset.link.Cookie\x12\x38\n\x0f\x66orm_credential\x18\x07 \x01(\x0b\x32\x1d.v3.asset.link.FormCredentialH\x01\x12<\n\x11script_credential\x18\x08 \x01(\x0b\x32\x1f.v3.asset.link.ScriptCredentialH\x01\x12&\n\x06parent\x18\t \x01(\x0b\x32\x16.v3.asset.link.Message\x12\x37\n\x12localstorage_items\x18\n \x03(\x0b\x32\x1b.v3.asset.link.LocalStorageB\x0c\n\nbody_oneofB\x12\n\x10\x63redential_oneof')
)




_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='v3.asset.link.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.link.Header.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v3.asset.link.Header.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=80,
)


_COOKIE = _descriptor.Descriptor(
  name='Cookie',
  full_name='v3.asset.link.Cookie',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.link.Cookie.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v3.asset.link.Cookie.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=119,
)


_LOCALSTORAGE = _descriptor.Descriptor(
  name='LocalStorage',
  full_name='v3.asset.link.LocalStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='v3.asset.link.LocalStorage.url', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='v3.asset.link.LocalStorage.key', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v3.asset.link.LocalStorage.value', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=176,
)


_FORMINPUT = _descriptor.Descriptor(
  name='FormInput',
  full_name='v3.asset.link.FormInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.link.FormInput.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v3.asset.link.FormInput.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='v3.asset.link.FormInput.type', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=232,
)


_FORM = _descriptor.Descriptor(
  name='Form',
  full_name='v3.asset.link.Form',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='v3.asset.link.Form.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enctype', full_name='v3.asset.link.Form.enctype', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=299,
)


_FORMCREDENTIAL = _descriptor.Descriptor(
  name='FormCredential',
  full_name='v3.asset.link.FormCredential',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='login', full_name='v3.asset.link.FormCredential.login', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='v3.asset.link.FormCredential.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='v3.asset.link.FormCredential.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=363,
)


_SCRIPTCREDENTIAL = _descriptor.Descriptor(
  name='ScriptCredential',
  full_name='v3.asset.link.ScriptCredential',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='v3.asset.link.ScriptCredential.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=399,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.asset.link.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='v3.asset.link.Message.url', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='v3.asset.link.Message.method', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='v3.asset.link.Message.body', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='form', full_name='v3.asset.link.Message.form', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_headers', full_name='v3.asset.link.Message.extra_headers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookies', full_name='v3.asset.link.Message.cookies', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='form_credential', full_name='v3.asset.link.Message.form_credential', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script_credential', full_name='v3.asset.link.Message.script_credential', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='v3.asset.link.Message.parent', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localstorage_items', full_name='v3.asset.link.Message.localstorage_items', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body_oneof', full_name='v3.asset.link.Message.body_oneof',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='credential_oneof', full_name='v3.asset.link.Message.credential_oneof',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=402,
  serialized_end=830,
)

_FORM.fields_by_name['inputs'].message_type = _FORMINPUT
_MESSAGE.fields_by_name['form'].message_type = _FORM
_MESSAGE.fields_by_name['extra_headers'].message_type = _HEADER
_MESSAGE.fields_by_name['cookies'].message_type = _COOKIE
_MESSAGE.fields_by_name['form_credential'].message_type = _FORMCREDENTIAL
_MESSAGE.fields_by_name['script_credential'].message_type = _SCRIPTCREDENTIAL
_MESSAGE.fields_by_name['parent'].message_type = _MESSAGE
_MESSAGE.fields_by_name['localstorage_items'].message_type = _LOCALSTORAGE
_MESSAGE.oneofs_by_name['body_oneof'].fields.append(
  _MESSAGE.fields_by_name['body'])
_MESSAGE.fields_by_name['body'].containing_oneof = _MESSAGE.oneofs_by_name['body_oneof']
_MESSAGE.oneofs_by_name['body_oneof'].fields.append(
  _MESSAGE.fields_by_name['form'])
_MESSAGE.fields_by_name['form'].containing_oneof = _MESSAGE.oneofs_by_name['body_oneof']
_MESSAGE.oneofs_by_name['credential_oneof'].fields.append(
  _MESSAGE.fields_by_name['form_credential'])
_MESSAGE.fields_by_name['form_credential'].containing_oneof = _MESSAGE.oneofs_by_name['credential_oneof']
_MESSAGE.oneofs_by_name['credential_oneof'].fields.append(
  _MESSAGE.fields_by_name['script_credential'])
_MESSAGE.fields_by_name['script_credential'].containing_oneof = _MESSAGE.oneofs_by_name['credential_oneof']
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Cookie'] = _COOKIE
DESCRIPTOR.message_types_by_name['LocalStorage'] = _LOCALSTORAGE
DESCRIPTOR.message_types_by_name['FormInput'] = _FORMINPUT
DESCRIPTOR.message_types_by_name['Form'] = _FORM
DESCRIPTOR.message_types_by_name['FormCredential'] = _FORMCREDENTIAL
DESCRIPTOR.message_types_by_name['ScriptCredential'] = _SCRIPTCREDENTIAL
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.Header)
  ))
_sym_db.RegisterMessage(Header)

Cookie = _reflection.GeneratedProtocolMessageType('Cookie', (_message.Message,), dict(
  DESCRIPTOR = _COOKIE,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.Cookie)
  ))
_sym_db.RegisterMessage(Cookie)

LocalStorage = _reflection.GeneratedProtocolMessageType('LocalStorage', (_message.Message,), dict(
  DESCRIPTOR = _LOCALSTORAGE,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.LocalStorage)
  ))
_sym_db.RegisterMessage(LocalStorage)

FormInput = _reflection.GeneratedProtocolMessageType('FormInput', (_message.Message,), dict(
  DESCRIPTOR = _FORMINPUT,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.FormInput)
  ))
_sym_db.RegisterMessage(FormInput)

Form = _reflection.GeneratedProtocolMessageType('Form', (_message.Message,), dict(
  DESCRIPTOR = _FORM,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.Form)
  ))
_sym_db.RegisterMessage(Form)

FormCredential = _reflection.GeneratedProtocolMessageType('FormCredential', (_message.Message,), dict(
  DESCRIPTOR = _FORMCREDENTIAL,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.FormCredential)
  ))
_sym_db.RegisterMessage(FormCredential)

ScriptCredential = _reflection.GeneratedProtocolMessageType('ScriptCredential', (_message.Message,), dict(
  DESCRIPTOR = _SCRIPTCREDENTIAL,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.ScriptCredential)
  ))
_sym_db.RegisterMessage(ScriptCredential)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGE,
  __module__ = 'v3.asset.link.link_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.link.Message)
  ))
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)



"""Create mobile scan API."""
import enum
import json
from typing import Dict, Optional, BinaryIO

from . import request


SCAN_PROFILES = {
    'fast_scan': 'Fast Scan',
    'full_scan': 'Full Scan'
}

class MobileAssetType(enum.Enum):
    ANDROID = enum.auto()
    IOS = enum.auto()


class CreateMobileScanAPIRequest(request.APIRequest):
    """Create mobile scan API from a file."""

    def __init__(self, title: str, asset_type: MobileAssetType, scan_profile: str, application: BinaryIO):
        self._title = title
        self._asset_type = asset_type
        self._scan_profile = scan_profile
        self._application = application

    @property
    def query(self) -> Optional[str]:
        """Defines the query to create a mobile scan.

        Returns:
            The query to create a mobile scan
        """

        return """
            mutation MobileScan($title: String!, $assetType: String!, $application: Upload!, $scanProfile: String!) {
                createMobileScan(title: $title, assetType: $assetType, application: $application, scanProfile: $scanProfile) {
                    scan {
                        id
                    }
                }
            }
        """

    @property
    def data(self) -> Optional[Dict]:
        """Sets the query and variables to create the scan.

        Returns:
            The query and variables to create a scan.
         """
        data = {
            'operations': json.dumps({'query': self.query,
                                      'variables': {'title': self._title,
                                                    'assetType': self._asset_type.name.lower(),
                                                    'application': None,
                                                    'scanProfile': self._scan_profile
                                                    }
                                      }
                                    ),
            'map': json.dumps({
                '0': ['variables.application'],
            })
        }
        return data

    @property
    def files(self) -> Optional[Dict] :
        """Sets the file for multipart upload to create the mobile scan.

        Returns:
            The file mapping to create a scan.
        """
        return {'0': self._application}



"""Vulnz Describe command."""
import logging
from typing import Optional

import click

from ostorlab.cli import console as cli_console
from ostorlab.cli.vulnz import vulnz
from ostorlab.runtimes.cloud import runtime as cloud_runtime
from ostorlab.runtimes.local import runtime as local_runtime

console = cli_console.Console()

logger = logging.getLogger(__name__)


@vulnz.command(name='describe')
@click.option('--vuln-id', '-v', 'vuln_id', help='Id of the vulnerability.', required=False)
@click.option('--scan-id', '-s', 'scan_id', help='Id of the scan.', required=False)
@click.pass_context
def describe_cli(ctx, vuln_id: Optional[int] = None, scan_id: Optional[int] = None) -> None:
    """Describe a vuln by id (--vuln-id) or all the vulnz for as specific scan.
        example of usage:
            - ostorlab vulnz --runtime cloud describe --scan-id 54821 """
    if isinstance(ctx.obj['runtime'], cloud_runtime.CloudRuntime) and scan_id is None:
        raise click.BadParameter('Please provide --scan-id / -s when using the cloud runtime')
    if isinstance(ctx.obj['runtime'], local_runtime.LocalRuntime) and scan_id is None and vuln_id is None:
        raise click.BadParameter('Please provide --scan-id / -s or --vuln-id / -v when using local runtime')
    runtime_instance = ctx.obj['runtime']
    console.info('Fetching vulnerabilities...')
    runtime_instance.describe_vuln(scan_id=scan_id, vuln_id=vuln_id)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: monitor_filesystem.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='monitor_filesystem.proto',
    package='',
    syntax='proto2',
    serialized_pb=_b(
        '\n\x18monitor_filesystem.proto\"\xd4\x01\n\x12monitor_filesystem\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x10\n\x08\x66ilename\x18\x02 \x02(\t\x12\x0b\n\x03pid\x18\x03 \x02(\x05\x12\x0b\n\x03uid\x18\x04 \x02(\x05\x12\x0b\n\x03gid\x18\x05 \x02(\x05\x12\x0c\n\x04mode\x18\x06 \x02(\x05\x12\x0c\n\x04ppid\x18\x07 \x02(\x05\x12\x0c\n\x04proc\x18\x08 \x02(\t\x12\x0c\n\x04type\x18\t \x02(\t\x12\x12\n\nuser_right\x18\n \x02(\t\x12\x13\n\x0bgroup_right\x18\x0b \x02(\t\x12\x13\n\x0bother_right\x18\x0c \x02(\t')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MONITOR_FILESYSTEM = _descriptor.Descriptor(
    name='monitor_filesystem',
    full_name='monitor_filesystem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='monitor_filesystem.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='filename', full_name='monitor_filesystem.filename', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='pid', full_name='monitor_filesystem.pid', index=2,
            number=3, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='uid', full_name='monitor_filesystem.uid', index=3,
            number=4, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='gid', full_name='monitor_filesystem.gid', index=4,
            number=5, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='mode', full_name='monitor_filesystem.mode', index=5,
            number=6, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='ppid', full_name='monitor_filesystem.ppid', index=6,
            number=7, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='proc', full_name='monitor_filesystem.proc', index=7,
            number=8, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='type', full_name='monitor_filesystem.type', index=8,
            number=9, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='user_right', full_name='monitor_filesystem.user_right', index=9,
            number=10, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='group_right', full_name='monitor_filesystem.group_right', index=10,
            number=11, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='other_right', full_name='monitor_filesystem.other_right', index=11,
            number=12, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=241,
)

DESCRIPTOR.message_types_by_name['monitor_filesystem'] = _MONITOR_FILESYSTEM

monitor_filesystem = _reflection.GeneratedProtocolMessageType('monitor_filesystem', (_message.Message,), dict(
    DESCRIPTOR=_MONITOR_FILESYSTEM,
    __module__='monitor_filesystem_pb2'
    # @@protoc_insertion_point(class_scope:monitor_filesystem)
))
_sym_db.RegisterMessage(monitor_filesystem)

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/asset/ip/v4/whois/whois.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/asset/ip/v4/whois/whois.proto',
  package='v3.asset.ip.v4.whois',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n v3/asset/ip/v4/whois/whois.proto\x12\x14v3.asset.ip.v4.whois\"L\n\x07Network\x12\x0c\n\x04\x63idr\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\t\x12\x15\n\rparent_handle\x18\x04 \x01(\t\"6\n\x07\x43ontact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"F\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x07\x63ontact\x18\x02 \x01(\x0b\x32\x1d.v3.asset.ip.v4.whois.Contact\"\x88\x02\n\x07Message\x12\x0c\n\x04host\x18\x01 \x02(\t\x12\x0c\n\x04mask\x18\x02 \x01(\t\x12\x12\n\x07version\x18\x03 \x02(\x05:\x01\x34\x12\x14\n\x0c\x61sn_registry\x18\x04 \x01(\t\x12\x12\n\nasn_number\x18\x05 \x01(\x05\x12\x18\n\x10\x61sn_country_code\x18\x06 \x01(\t\x12\x10\n\x08\x61sn_date\x18\x07 \x01(\t\x12\x17\n\x0f\x61sn_description\x18\x08 \x01(\t\x12.\n\x07network\x18\t \x01(\x0b\x32\x1d.v3.asset.ip.v4.whois.Network\x12.\n\x08\x65ntities\x18\n \x03(\x0b\x32\x1c.v3.asset.ip.v4.whois.Entity'
)




_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='v3.asset.ip.v4.whois.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cidr', full_name='v3.asset.ip.v4.whois.Network.cidr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.ip.v4.whois.Network.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='handle', full_name='v3.asset.ip.v4.whois.Network.handle', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_handle', full_name='v3.asset.ip.v4.whois.Network.parent_handle', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=134,
)


_CONTACT = _descriptor.Descriptor(
  name='Contact',
  full_name='v3.asset.ip.v4.whois.Contact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.ip.v4.whois.Contact.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='v3.asset.ip.v4.whois.Contact.kind', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='v3.asset.ip.v4.whois.Contact.address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=190,
)


_ENTITY = _descriptor.Descriptor(
  name='Entity',
  full_name='v3.asset.ip.v4.whois.Entity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.ip.v4.whois.Entity.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='v3.asset.ip.v4.whois.Entity.contact', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=262,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.asset.ip.v4.whois.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='v3.asset.ip.v4.whois.Message.host', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mask', full_name='v3.asset.ip.v4.whois.Message.mask', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='v3.asset.ip.v4.whois.Message.version', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asn_registry', full_name='v3.asset.ip.v4.whois.Message.asn_registry', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asn_number', full_name='v3.asset.ip.v4.whois.Message.asn_number', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asn_country_code', full_name='v3.asset.ip.v4.whois.Message.asn_country_code', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asn_date', full_name='v3.asset.ip.v4.whois.Message.asn_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asn_description', full_name='v3.asset.ip.v4.whois.Message.asn_description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network', full_name='v3.asset.ip.v4.whois.Message.network', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entities', full_name='v3.asset.ip.v4.whois.Message.entities', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=529,
)

_ENTITY.fields_by_name['contact'].message_type = _CONTACT
_MESSAGE.fields_by_name['network'].message_type = _NETWORK
_MESSAGE.fields_by_name['entities'].message_type = _ENTITY
DESCRIPTOR.message_types_by_name['Network'] = _NETWORK
DESCRIPTOR.message_types_by_name['Contact'] = _CONTACT
DESCRIPTOR.message_types_by_name['Entity'] = _ENTITY
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Network = _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
  'DESCRIPTOR' : _NETWORK,
  '__module__' : 'v3.asset.ip.v4.whois.whois_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.ip.v4.whois.Network)
  })
_sym_db.RegisterMessage(Network)

Contact = _reflection.GeneratedProtocolMessageType('Contact', (_message.Message,), {
  'DESCRIPTOR' : _CONTACT,
  '__module__' : 'v3.asset.ip.v4.whois.whois_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.ip.v4.whois.Contact)
  })
_sym_db.RegisterMessage(Contact)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), {
  'DESCRIPTOR' : _ENTITY,
  '__module__' : 'v3.asset.ip.v4.whois.whois_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.ip.v4.whois.Entity)
  })
_sym_db.RegisterMessage(Entity)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'v3.asset.ip.v4.whois.whois_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.ip.v4.whois.Message)
  })
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ide_request.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='ide_request.proto',
    package='',
    serialized_pb=_b(
        '\n\x16request_response.proto\"%\n\x06header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"N\n\x07request\x12\x0e\n\x06method\x18\x01 \x02(\t\x12\x0b\n\x03url\x18\x02 \x02(\t\x12\x18\n\x07headers\x18\x03 \x03(\x0b\x32\x07.header\x12\x0c\n\x04\x62ody\x18\x04 \x01(\x0c\"\x9e\x01\n\x08response\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\x0e\n\x06status\x18\x02 \x02(\x05\x12\x13\n\x0bstatus_text\x18\x03 \x02(\t\x12\x18\n\x07headers\x18\x04 \x03(\x0b\x32\x07.header\x12\x11\n\tremote_ip\x18\x05 \x01(\t\x12\x13\n\x0bremote_port\x18\x06 \x01(\x05\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x0c\n\x04\x62ody\x18\x08 \x01(\x0c\"[\n\x10request_response\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x19\n\x07request\x18\x02 \x02(\x0b\x32\x08.request\x12\x1b\n\x08response\x18\x03 \x01(\x0b\x32\t.response')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_HEADER = _descriptor.Descriptor(
    name='header',
    full_name='header',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='header.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='header.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=26,
    serialized_end=63,
)

_REQUEST = _descriptor.Descriptor(
    name='request',
    full_name='request',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='method', full_name='request.method', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='request.url', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='headers', full_name='request.headers', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='request.body', index=3,
            number=4, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=65,
    serialized_end=143,
)

_RESPONSE = _descriptor.Descriptor(
    name='response',
    full_name='response',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='url', full_name='response.url', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='status', full_name='response.status', index=1,
            number=2, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='status_text', full_name='response.status_text', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='headers', full_name='response.headers', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='remote_ip', full_name='response.remote_ip', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='remote_port', full_name='response.remote_port', index=5,
            number=6, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='protocol', full_name='response.protocol', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='response.body', index=7,
            number=8, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=146,
    serialized_end=304,
)

_REQUEST_RESPONSE = _descriptor.Descriptor(
    name='request_response',
    full_name='request_response',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='request_response.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='request', full_name='request_response.request', index=1,
            number=2, type=11, cpp_type=10, label=2,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='response', full_name='request_response.response', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=306,
    serialized_end=397,
)

_REQUEST.fields_by_name['headers'].message_type = _HEADER
_RESPONSE.fields_by_name['headers'].message_type = _HEADER
_REQUEST_RESPONSE.fields_by_name['request'].message_type = _REQUEST
_REQUEST_RESPONSE.fields_by_name['response'].message_type = _RESPONSE
DESCRIPTOR.message_types_by_name['header'] = _HEADER
DESCRIPTOR.message_types_by_name['request'] = _REQUEST
DESCRIPTOR.message_types_by_name['response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['request_response'] = _REQUEST_RESPONSE

header = _reflection.GeneratedProtocolMessageType('header', (_message.Message,), dict(
    DESCRIPTOR=_HEADER,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:header)
))
_sym_db.RegisterMessage(header)

request = _reflection.GeneratedProtocolMessageType('request', (_message.Message,), dict(
    DESCRIPTOR=_REQUEST,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:request)
))
_sym_db.RegisterMessage(request)

response = _reflection.GeneratedProtocolMessageType('response', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSE,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:response)
))
_sym_db.RegisterMessage(response)

request_response = _reflection.GeneratedProtocolMessageType('request_response', (_message.Message,), dict(
    DESCRIPTOR=_REQUEST_RESPONSE,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:request_response)
))
_sym_db.RegisterMessage(request_response)

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: extracted.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='extracted.proto',
    package='',
    syntax='proto2',
    serialized_pb=_b(
        '\n\x0f\x65xtracted.proto\":\n\x1blink_extracted_extra_header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"4\n\x15link_extracted_cookie\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"F\n\x19link_extracted_form_input\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\"R\n\x13link_extracted_form\x12*\n\x06inputs\x18\x01 \x03(\x0b\x32\x1a.link_extracted_form_input\x12\x0f\n\x07\x65nctype\x18\x02 \x02(\t\"R\n\x14\x65xtracted_credential\x12\x0c\n\x04type\x18\x01 \x02(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\xb3\x02\n\textracted\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x0f\n\x07link_id\x18\x02 \x01(\x05\x12\x0b\n\x03url\x18\x03 \x02(\t\x12\x0e\n\x06method\x18\x04 \x02(\t\x12\x0e\n\x04\x62ody\x18\x05 \x01(\x0cH\x00\x12$\n\x04\x66orm\x18\x06 \x01(\x0b\x32\x14.link_extracted_formH\x00\x12\x33\n\rextra_headers\x18\x07 \x03(\x0b\x32\x1c.link_extracted_extra_header\x12\'\n\x07\x63ookies\x18\x08 \x03(\x0b\x32\x16.link_extracted_cookie\x12)\n\ncredential\x18\t \x01(\x0b\x32\x15.extracted_credential\x12\x1a\n\x06parent\x18\n \x01(\x0b\x32\n.extractedB\x0c\n\nbody_oneof')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_LINK_EXTRACTED_EXTRA_HEADER = _descriptor.Descriptor(
    name='link_extracted_extra_header',
    full_name='link_extracted_extra_header',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_extracted_extra_header.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_extracted_extra_header.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=19,
    serialized_end=77,
)

_LINK_EXTRACTED_COOKIE = _descriptor.Descriptor(
    name='link_extracted_cookie',
    full_name='link_extracted_cookie',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_extracted_cookie.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_extracted_cookie.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=79,
    serialized_end=131,
)

_LINK_EXTRACTED_FORM_INPUT = _descriptor.Descriptor(
    name='link_extracted_form_input',
    full_name='link_extracted_form_input',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_extracted_form_input.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_extracted_form_input.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='type', full_name='link_extracted_form_input.type', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=133,
    serialized_end=203,
)

_LINK_EXTRACTED_FORM = _descriptor.Descriptor(
    name='link_extracted_form',
    full_name='link_extracted_form',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='inputs', full_name='link_extracted_form.inputs', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='enctype', full_name='link_extracted_form.enctype', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=205,
    serialized_end=287,
)

_EXTRACTED_CREDENTIAL = _descriptor.Descriptor(
    name='extracted_credential',
    full_name='extracted_credential',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='extracted_credential.type', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='login', full_name='extracted_credential.login', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='password', full_name='extracted_credential.password', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='extracted_credential.url', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=289,
    serialized_end=371,
)

_EXTRACTED = _descriptor.Descriptor(
    name='extracted',
    full_name='extracted',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='extracted.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='link_id', full_name='extracted.link_id', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='extracted.url', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='method', full_name='extracted.method', index=3,
            number=4, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='extracted.body', index=4,
            number=5, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='form', full_name='extracted.form', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='extra_headers', full_name='extracted.extra_headers', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='cookies', full_name='extracted.cookies', index=7,
            number=8, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='credential', full_name='extracted.credential', index=8,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='parent', full_name='extracted.parent', index=9,
            number=10, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='body_oneof', full_name='extracted.body_oneof',
            index=0, containing_type=None, fields=[]),
    ],
    serialized_start=374,
    serialized_end=681,
)

_LINK_EXTRACTED_FORM.fields_by_name['inputs'].message_type = _LINK_EXTRACTED_FORM_INPUT
_EXTRACTED.fields_by_name['form'].message_type = _LINK_EXTRACTED_FORM
_EXTRACTED.fields_by_name['extra_headers'].message_type = _LINK_EXTRACTED_EXTRA_HEADER
_EXTRACTED.fields_by_name['cookies'].message_type = _LINK_EXTRACTED_COOKIE
_EXTRACTED.fields_by_name['credential'].message_type = _EXTRACTED_CREDENTIAL
_EXTRACTED.fields_by_name['parent'].message_type = _EXTRACTED
_EXTRACTED.oneofs_by_name['body_oneof'].fields.append(
    _EXTRACTED.fields_by_name['body'])
_EXTRACTED.fields_by_name['body'].containing_oneof = _EXTRACTED.oneofs_by_name['body_oneof']
_EXTRACTED.oneofs_by_name['body_oneof'].fields.append(
    _EXTRACTED.fields_by_name['form'])
_EXTRACTED.fields_by_name['form'].containing_oneof = _EXTRACTED.oneofs_by_name['body_oneof']
DESCRIPTOR.message_types_by_name['link_extracted_extra_header'] = _LINK_EXTRACTED_EXTRA_HEADER
DESCRIPTOR.message_types_by_name['link_extracted_cookie'] = _LINK_EXTRACTED_COOKIE
DESCRIPTOR.message_types_by_name['link_extracted_form_input'] = _LINK_EXTRACTED_FORM_INPUT
DESCRIPTOR.message_types_by_name['link_extracted_form'] = _LINK_EXTRACTED_FORM
DESCRIPTOR.message_types_by_name['extracted_credential'] = _EXTRACTED_CREDENTIAL
DESCRIPTOR.message_types_by_name['extracted'] = _EXTRACTED

link_extracted_extra_header = _reflection.GeneratedProtocolMessageType('link_extracted_extra_header',
                                                                       (_message.Message,), dict(
        DESCRIPTOR=_LINK_EXTRACTED_EXTRA_HEADER,
        __module__='extracted_pb2'
        # @@protoc_insertion_point(class_scope:link_extracted_extra_header)
    ))
_sym_db.RegisterMessage(link_extracted_extra_header)

link_extracted_cookie = _reflection.GeneratedProtocolMessageType('link_extracted_cookie', (_message.Message,), dict(
    DESCRIPTOR=_LINK_EXTRACTED_COOKIE,
    __module__='extracted_pb2'
    # @@protoc_insertion_point(class_scope:link_extracted_cookie)
))
_sym_db.RegisterMessage(link_extracted_cookie)

link_extracted_form_input = _reflection.GeneratedProtocolMessageType('link_extracted_form_input', (_message.Message,),
                                                                     dict(
                                                                         DESCRIPTOR=_LINK_EXTRACTED_FORM_INPUT,
                                                                         __module__='extracted_pb2'
                                                                         # @@protoc_insertion_point(class_scope:link_extracted_form_input)
                                                                     ))
_sym_db.RegisterMessage(link_extracted_form_input)

link_extracted_form = _reflection.GeneratedProtocolMessageType('link_extracted_form', (_message.Message,), dict(
    DESCRIPTOR=_LINK_EXTRACTED_FORM,
    __module__='extracted_pb2'
    # @@protoc_insertion_point(class_scope:link_extracted_form)
))
_sym_db.RegisterMessage(link_extracted_form)

extracted_credential = _reflection.GeneratedProtocolMessageType('extracted_credential', (_message.Message,), dict(
    DESCRIPTOR=_EXTRACTED_CREDENTIAL,
    __module__='extracted_pb2'
    # @@protoc_insertion_point(class_scope:extracted_credential)
))
_sym_db.RegisterMessage(extracted_credential)

extracted = _reflection.GeneratedProtocolMessageType('extracted', (_message.Message,), dict(
    DESCRIPTOR=_EXTRACTED,
    __module__='extracted_pb2'
    # @@protoc_insertion_point(class_scope:extracted)
))
_sym_db.RegisterMessage(extracted)

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: end_processing.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='end_processing.proto',
    package='',
    syntax='proto2',
    serialized_pb=_b(
        '\n\x14\x65nd_processing.proto\"\x7f\n\x0e\x65nd_processing\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x0e\n\x06source\x18\x02 \x02(\t\x12\x1f\n\x07message\x18\x03 \x01(\t:\x0e\x65nd_processing\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x16\n\x0e\x63orrelation_id\x18\x05 \x02(\t')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_END_PROCESSING = _descriptor.Descriptor(
    name='end_processing',
    full_name='end_processing',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='end_processing.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='source', full_name='end_processing.source', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='message', full_name='end_processing.message', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=True, default_value=_b("end_processing").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='description', full_name='end_processing.description', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='correlation_id', full_name='end_processing.correlation_id', index=4,
            number=5, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=24,
    serialized_end=151,
)

DESCRIPTOR.message_types_by_name['end_processing'] = _END_PROCESSING

end_processing = _reflection.GeneratedProtocolMessageType('end_processing', (_message.Message,), dict(
    DESCRIPTOR=_END_PROCESSING,
    __module__='end_processing_pb2'
    # @@protoc_insertion_point(class_scope:end_processing)
))
_sym_db.RegisterMessage(end_processing)

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: elf.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='elf.proto',
    package='',
    syntax='proto2',
    serialized_options=None,
    serialized_pb=_b(
        '\n\telf.proto\"=\n\x03\x65lf\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x10\n\x08\x66ilename\x18\x02 \x02(\t\x12\x13\n\x0b\x66ilecontent\x18\x03 \x02(\x0c')
)

_ELF = _descriptor.Descriptor(
    name='elf',
    full_name='elf',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='elf.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='filename', full_name='elf.filename', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='filecontent', full_name='elf.filecontent', index=2,
            number=3, type=12, cpp_type=9, label=2,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=13,
    serialized_end=74,
)

DESCRIPTOR.message_types_by_name['elf'] = _ELF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

elf = _reflection.GeneratedProtocolMessageType('elf', (_message.Message,), dict(
    DESCRIPTOR=_ELF,
    __module__='elf_pb2'
    # @@protoc_insertion_point(class_scope:elf)
))
_sym_db.RegisterMessage(elf)

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scan_start.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='scan_start.proto',
    package='',
    syntax='proto2',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x10scan_start.proto\"\x1b\n\x06\x64\x65vice\x12\x11\n\tdevice_id\x18\x01 \x02(\t\"m\n\nscan_start\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x10\n\x08platform\x18\x02 \x02(\t\x12\x14\n\x0cpackage_name\x18\x03 \x02(\t\x12\x0c\n\x04\x66ile\x18\x04 \x02(\x0c\x12\x18\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x07.device')
)

_DEVICE = _descriptor.Descriptor(
    name='device',
    full_name='device',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='device_id', full_name='device.device_id', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=20,
    serialized_end=47,
)

_SCAN_START = _descriptor.Descriptor(
    name='scan_start',
    full_name='scan_start',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='scan_start.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='platform', full_name='scan_start.platform', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='package_name', full_name='scan_start.package_name', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='file', full_name='scan_start.file', index=3,
            number=4, type=12, cpp_type=9, label=2,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='devices', full_name='scan_start.devices', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=49,
    serialized_end=158,
)

_SCAN_START.fields_by_name['devices'].message_type = _DEVICE
DESCRIPTOR.message_types_by_name['device'] = _DEVICE
DESCRIPTOR.message_types_by_name['scan_start'] = _SCAN_START
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

device = _reflection.GeneratedProtocolMessageType('device', (_message.Message,), dict(
    DESCRIPTOR=_DEVICE,
    __module__='scan_start_pb2'
    # @@protoc_insertion_point(class_scope:device)
))
_sym_db.RegisterMessage(device)

scan_start = _reflection.GeneratedProtocolMessageType('scan_start', (_message.Message,), dict(
    DESCRIPTOR=_SCAN_START,
    __module__='scan_start_pb2'
    # @@protoc_insertion_point(class_scope:scan_start)
))
_sym_db.RegisterMessage(scan_start)

# @@protoc_insertion_point(module_scope)



"""Define methods to style components for console."""


def style_risk(risk: str) -> str:
    """Stylize the risk with colors."""
    if risk == 'HIGH':
        return '[bold bright_white on red]High[/]'
    elif risk == 'MEDIUM':
        return '[bold bright_white on yellow]Medium[/]'
    elif risk == 'LOW':
        return '[bold bright_white on bright_yellow]Low[/]'
    else:
        return risk


def style_progress(progress: str) -> str:
    """Stylize the scan progress with colors."""
    if progress == 'done':
        return '[bold green4]Done[/]'
    if progress == 'error':
        return '[bold magenta]Error[/]'
    if progress == 'not_started':
        return '[bold bright_black]Not Started[/]'
    if progress == 'stopped':
        return '[bold bright_red]Stopped[/]'
    if progress == 'in_progress':
        return '[bold bright_cyan]Running[/]'
    else:
        return progress


def style_asset(asset: str) -> str:
    """Stylize the scan asset with colors and emojis."""
    if asset == 'android_store':
        return '[bold green4]:iphone: Android Store[/]'
    elif asset == 'ios_store':
        return '[bold bright_white]:apple: iOS Store[/]'
    elif asset == 'android':
        return '[bold bright_green]:iphone: Android[/]'
    elif asset == 'ios':
        return '[bold white]:apple: iOS[/]'
    else:
        return asset



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: link.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='link.proto',
    package='',
    syntax='proto2',
    serialized_pb=_b(
        '\n\nlink.proto\"0\n\x11link_extra_header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"*\n\x0blink_cookie\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"<\n\x0flink_form_input\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\">\n\tlink_form\x12 \n\x06inputs\x18\x01 \x03(\x0b\x32\x10.link_form_input\x12\x0f\n\x07\x65nctype\x18\x02 \x02(\t\"M\n\x0flink_credential\x12\x0c\n\x04type\x18\x01 \x02(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\x86\x02\n\x04link\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x0f\n\x07link_id\x18\x02 \x01(\x05\x12\x0b\n\x03url\x18\x03 \x02(\t\x12\x0e\n\x06method\x18\x04 \x02(\t\x12\x0e\n\x04\x62ody\x18\x05 \x01(\x0cH\x00\x12\x1a\n\x04\x66orm\x18\x06 \x01(\x0b\x32\n.link_formH\x00\x12)\n\rextra_headers\x18\x07 \x03(\x0b\x32\x12.link_extra_header\x12\x1d\n\x07\x63ookies\x18\x08 \x03(\x0b\x32\x0c.link_cookie\x12$\n\ncredential\x18\t \x01(\x0b\x32\x10.link_credential\x12\x15\n\x06parent\x18\n \x01(\x0b\x32\x05.linkB\x0c\n\nbody_oneof')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_LINK_EXTRA_HEADER = _descriptor.Descriptor(
    name='link_extra_header',
    full_name='link_extra_header',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_extra_header.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_extra_header.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=14,
    serialized_end=62,
)

_LINK_COOKIE = _descriptor.Descriptor(
    name='link_cookie',
    full_name='link_cookie',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_cookie.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_cookie.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=64,
    serialized_end=106,
)

_LINK_FORM_INPUT = _descriptor.Descriptor(
    name='link_form_input',
    full_name='link_form_input',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_form_input.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_form_input.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='type', full_name='link_form_input.type', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=108,
    serialized_end=168,
)

_LINK_FORM = _descriptor.Descriptor(
    name='link_form',
    full_name='link_form',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='inputs', full_name='link_form.inputs', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='enctype', full_name='link_form.enctype', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=170,
    serialized_end=232,
)

_LINK_CREDENTIAL = _descriptor.Descriptor(
    name='link_credential',
    full_name='link_credential',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='link_credential.type', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='login', full_name='link_credential.login', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='password', full_name='link_credential.password', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='link_credential.url', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=234,
    serialized_end=311,
)

_LINK = _descriptor.Descriptor(
    name='link',
    full_name='link',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='link.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='link_id', full_name='link.link_id', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='link.url', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='method', full_name='link.method', index=3,
            number=4, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='link.body', index=4,
            number=5, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='form', full_name='link.form', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='extra_headers', full_name='link.extra_headers', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='cookies', full_name='link.cookies', index=7,
            number=8, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='credential', full_name='link.credential', index=8,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='parent', full_name='link.parent', index=9,
            number=10, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='body_oneof', full_name='link.body_oneof',
            index=0, containing_type=None, fields=[]),
    ],
    serialized_start=314,
    serialized_end=576,
)

_LINK_FORM.fields_by_name['inputs'].message_type = _LINK_FORM_INPUT
_LINK.fields_by_name['form'].message_type = _LINK_FORM
_LINK.fields_by_name['extra_headers'].message_type = _LINK_EXTRA_HEADER
_LINK.fields_by_name['cookies'].message_type = _LINK_COOKIE
_LINK.fields_by_name['credential'].message_type = _LINK_CREDENTIAL
_LINK.fields_by_name['parent'].message_type = _LINK
_LINK.oneofs_by_name['body_oneof'].fields.append(
    _LINK.fields_by_name['body'])
_LINK.fields_by_name['body'].containing_oneof = _LINK.oneofs_by_name['body_oneof']
_LINK.oneofs_by_name['body_oneof'].fields.append(
    _LINK.fields_by_name['form'])
_LINK.fields_by_name['form'].containing_oneof = _LINK.oneofs_by_name['body_oneof']
DESCRIPTOR.message_types_by_name['link_extra_header'] = _LINK_EXTRA_HEADER
DESCRIPTOR.message_types_by_name['link_cookie'] = _LINK_COOKIE
DESCRIPTOR.message_types_by_name['link_form_input'] = _LINK_FORM_INPUT
DESCRIPTOR.message_types_by_name['link_form'] = _LINK_FORM
DESCRIPTOR.message_types_by_name['link_credential'] = _LINK_CREDENTIAL
DESCRIPTOR.message_types_by_name['link'] = _LINK

link_extra_header = _reflection.GeneratedProtocolMessageType('link_extra_header', (_message.Message,), dict(
    DESCRIPTOR=_LINK_EXTRA_HEADER,
    __module__='link_pb2'
    # @@protoc_insertion_point(class_scope:link_extra_header)
))
_sym_db.RegisterMessage(link_extra_header)

link_cookie = _reflection.GeneratedProtocolMessageType('link_cookie', (_message.Message,), dict(
    DESCRIPTOR=_LINK_COOKIE,
    __module__='link_pb2'
    # @@protoc_insertion_point(class_scope:link_cookie)
))
_sym_db.RegisterMessage(link_cookie)

link_form_input = _reflection.GeneratedProtocolMessageType('link_form_input', (_message.Message,), dict(
    DESCRIPTOR=_LINK_FORM_INPUT,
    __module__='link_pb2'
    # @@protoc_insertion_point(class_scope:link_form_input)
))
_sym_db.RegisterMessage(link_form_input)

link_form = _reflection.GeneratedProtocolMessageType('link_form', (_message.Message,), dict(
    DESCRIPTOR=_LINK_FORM,
    __module__='link_pb2'
    # @@protoc_insertion_point(class_scope:link_form)
))
_sym_db.RegisterMessage(link_form)

link_credential = _reflection.GeneratedProtocolMessageType('link_credential', (_message.Message,), dict(
    DESCRIPTOR=_LINK_CREDENTIAL,
    __module__='link_pb2'
    # @@protoc_insertion_point(class_scope:link_credential)
))
_sym_db.RegisterMessage(link_credential)

link = _reflection.GeneratedProtocolMessageType('link', (_message.Message,), dict(
    DESCRIPTOR=_LINK,
    __module__='link_pb2'
    # @@protoc_insertion_point(class_scope:link)
))
_sym_db.RegisterMessage(link)

# @@protoc_insertion_point(module_scope)



"""Agent and Agent group definitions and settings dataclasses."""
import dataclasses
import io
from typing import List, Optional, Dict, Any

from ostorlab.agent.schema import loader
from ostorlab.utils import defintions


@dataclasses.dataclass
class AgentDefinition:
    """Data class holding attributes of an agent."""
    name: str
    in_selectors: List[str] = dataclasses.field(default_factory=list)
    out_selectors: List[str] = dataclasses.field(default_factory=list)
    args: List[Dict[str, Any]] = dataclasses.field(default_factory=list)
    constraints: List[str] = dataclasses.field(default_factory=list)
    mounts: List[str] = dataclasses.field(default_factory=list)
    restart_policy: str = 'any'
    mem_limit: int = None
    open_ports: List[defintions.PortMapping] = dataclasses.field(default_factory=list)
    restrictions: List[str] = dataclasses.field(default_factory=list)
    version: Optional[str] = None
    description: Optional[str] = None
    source: Optional[str] = None
    license: Optional[str] = None
    durability: str = 'published'
    docker_file_path: str = 'Dockerfile'
    docker_build_root: str = '.'
    image: str = None
    service_name: str = None

    @classmethod
    def from_yaml(cls, file: io.FileIO) -> 'AgentDefinition':
        """Constructs an agent definition from a yaml definition file.

        Args:
            file: Yaml file.

        Returns:
            Agent definition.
        """
        definition = loader.load_agent_yaml(file)
        return cls(
            name=definition.get('name'),
            in_selectors=definition.get('in_selectors'),
            out_selectors=definition.get('out_selectors'),
            args=definition.get('args', []),
            constraints=definition.get('constraints', []),
            mounts=definition.get('mounts', []),
            restart_policy=definition.get('restart_policy', 'any'),
            mem_limit=definition.get('mem_limit'),
            open_ports=definition.get('open_ports', []),
            restrictions=definition.get('restrictions', []),
            version=definition.get('version'),
            description=definition.get('description'),
            source=definition.get('source'),
            license=definition.get('license'),
            durability=definition.get('durability', 'published'),
            docker_file_path=definition.get('docker_file_path', 'Dockerfile'),
            docker_build_root=definition.get('docker_build_root', '.'),
            image=definition.get('image'),
            service_name=definition.get('service_name'),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/asset/domain_name/whois/whois.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/asset/domain_name/whois/whois.proto',
  package='v3.asset.domain_name.whois',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&v3/asset/domain_name/whois/whois.proto\x12\x1av3.asset.domain_name.whois\"\xd5\x02\n\x07Message\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x11\n\tregistrar\x18\x02 \x01(\t\x12\x14\n\x0cwhois_server\x18\x03 \x01(\t\x12\x14\n\x0creferral_url\x18\x04 \x01(\t\x12\x14\n\x0cupdated_date\x18\x05 \x03(\t\x12\x15\n\rcreation_date\x18\x06 \x03(\t\x12\x17\n\x0f\x65xpiration_date\x18\x07 \x03(\t\x12\x14\n\x0cname_servers\x18\x08 \x03(\t\x12\x0e\n\x06status\x18\t \x03(\t\x12\x0e\n\x06\x65mails\x18\n \x03(\t\x12\x0e\n\x06\x64nssec\x18\x0b \x03(\t\x12\x14\n\x0c\x63ontact_name\x18\x0c \x01(\t\x12\x0b\n\x03org\x18\r \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x0e \x01(\t\x12\x0c\n\x04\x63ity\x18\x0f \x01(\t\x12\r\n\x05state\x18\x10 \x01(\t\x12\x0f\n\x07zipcode\x18\x11 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x12 \x01(\t'
)




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.asset.domain_name.whois.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.asset.domain_name.whois.Message.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registrar', full_name='v3.asset.domain_name.whois.Message.registrar', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='whois_server', full_name='v3.asset.domain_name.whois.Message.whois_server', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referral_url', full_name='v3.asset.domain_name.whois.Message.referral_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_date', full_name='v3.asset.domain_name.whois.Message.updated_date', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_date', full_name='v3.asset.domain_name.whois.Message.creation_date', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_date', full_name='v3.asset.domain_name.whois.Message.expiration_date', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_servers', full_name='v3.asset.domain_name.whois.Message.name_servers', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='v3.asset.domain_name.whois.Message.status', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emails', full_name='v3.asset.domain_name.whois.Message.emails', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dnssec', full_name='v3.asset.domain_name.whois.Message.dnssec', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact_name', full_name='v3.asset.domain_name.whois.Message.contact_name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='org', full_name='v3.asset.domain_name.whois.Message.org', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='v3.asset.domain_name.whois.Message.address', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='v3.asset.domain_name.whois.Message.city', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='v3.asset.domain_name.whois.Message.state', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zipcode', full_name='v3.asset.domain_name.whois.Message.zipcode', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='v3.asset.domain_name.whois.Message.country', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=412,
)

DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'v3.asset.domain_name.whois.whois_pb2'
  # @@protoc_insertion_point(class_scope:v3.asset.domain_name.whois.Message)
  })
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)



"""KB provides automatic mapping from the KB entry folder name to the meta content."""
import dataclasses
import json
import pathlib

from typing import Dict

KB_FOLDER = 'KB'
META_JSON = 'meta.json'
DESCRIPTION = 'description.md'
RECOMMENDATION = 'recommendation.md'


@dataclasses.dataclass
class Entry:
    """KB entry with information like title, risk rating and description."""
    title: str
    risk_rating: str
    references: Dict[str, str]
    short_description: str = ''
    description: str = ''
    recommendation: str = ''
    security_issue: bool = False
    privacy_issue: bool = False
    has_public_exploit: bool = False
    targeted_by_malware: bool = False
    targeted_by_ransomware: bool = False
    targeted_by_nation_state: bool = False
    cvss_v3_vector: str = ''


class MetaKB(type):
    """Handles KB mapping to appropriate folder."""

    def __getattr__(cls, item):
        kb_path = pathlib.Path(__file__).parent / KB_FOLDER / item

        if not (kb_path / META_JSON).exists():
            raise ValueError(f'{kb_path} does not have a mapping.')
        with (kb_path / META_JSON).open(encoding='utf-8') as f, (kb_path / DESCRIPTION).open(encoding='utf-8') as d, (
                kb_path / RECOMMENDATION).open(encoding='utf-8') as r:
            meta = json.loads(f.read())
            return Entry(
                title=meta.get('title'),
                risk_rating=meta.get('risk_rating'),
                short_description=meta.get('short_description'),
                description=d.read(),
                recommendation=r.read(),
                references=meta.get('references'),
                security_issue=meta.get('security_issue', False),
                privacy_issue=meta.get('privacy_issue', False),
                has_public_exploit=meta.get('has_public_exploit', False),
                targeted_by_malware=meta.get('targeted_by_malware', False),
                targeted_by_ransomware=meta.get('targeted_by_ransomware', False),
                targeted_by_nation_state=meta.get('targeted_by_nation_state', False),
                cvss_v3_vector=meta.get('cvss_v3_vector', ''),
            )


class KB(object, metaclass=MetaKB):
    """Vulnerability knowledge base dispatcher."""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/fingerprint/file/library/library.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/fingerprint/file/library/library.proto',
  package='v3.fingerprint.file.library',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)v3/fingerprint/file/library/library.proto\x12\x1bv3.fingerprint.file.library\"t\n\x07Message\x12\x14\n\x0clibrary_path\x18\x01 \x02(\t\x12\x14\n\x0clibrary_name\x18\x02 \x02(\t\x12\x17\n\x0flibrary_version\x18\x03 \x01(\t\x12\x14\n\x0clibrary_type\x18\x04 \x02(\t\x12\x0e\n\x06\x64\x65tail\x18\x05 \x02(\t'
)




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.fingerprint.file.library.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='library_path', full_name='v3.fingerprint.file.library.Message.library_path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_name', full_name='v3.fingerprint.file.library.Message.library_name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_version', full_name='v3.fingerprint.file.library.Message.library_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_type', full_name='v3.fingerprint.file.library.Message.library_type', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detail', full_name='v3.fingerprint.file.library.Message.detail', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=190,
)

DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'v3.fingerprint.file.library.library_pb2'
  # @@protoc_insertion_point(class_scope:v3.fingerprint.file.library.Message)
  })
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/capture/http/request/request.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/capture/http/request/request.proto',
  package='v3.capture.http.request',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%v3/capture/http/request/request.proto\x12\x17v3.capture.http.request\"%\n\x06header\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\r\n\x05value\x18\x02 \x02(\x0c\"\xde\x01\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x02(\t\x12\x30\n\x07headers\x18\x03 \x03(\x0b\x32\x1f.v3.capture.http.request.header\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12\x14\n\x0chttp_version\x18\x07 \x01(\x0c\x12\x0e\n\x06scheme\x18\x08 \x01(\x0c\x12\x0c\n\x04path\x18\t \x01(\x0c\x12\x12\n\ntime_start\x18\n \x01(\x02\x12\x10\n\x08time_end\x18\x0b \x01(\x02'
)




_HEADER = _descriptor.Descriptor(
  name='header',
  full_name='v3.capture.http.request.header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v3.capture.http.request.header.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v3.capture.http.request.header.value', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=103,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.capture.http.request.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v3.capture.http.request.Message.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='v3.capture.http.request.Message.method', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='v3.capture.http.request.Message.headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='v3.capture.http.request.Message.content', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='v3.capture.http.request.Message.host', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='v3.capture.http.request.Message.port', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_version', full_name='v3.capture.http.request.Message.http_version', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='v3.capture.http.request.Message.scheme', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='v3.capture.http.request.Message.path', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_start', full_name='v3.capture.http.request.Message.time_start', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_end', full_name='v3.capture.http.request.Message.time_end', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=328,
)

_MESSAGE.fields_by_name['headers'].message_type = _HEADER
DESCRIPTOR.message_types_by_name['header'] = _HEADER
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

header = _reflection.GeneratedProtocolMessageType('header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'v3.capture.http.request.request_pb2'
  # @@protoc_insertion_point(class_scope:v3.capture.http.request.header)
  })
_sym_db.RegisterMessage(header)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'v3.capture.http.request.request_pb2'
  # @@protoc_insertion_point(class_scope:v3.capture.http.request.Message)
  })
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)
